package com.ynet.life.file.parser;

import com.lowagie.text.BadElementException;
import com.lowagie.text.Cell;
import com.lowagie.text.Document;
import com.lowagie.text.Font;
import com.lowagie.text.Paragraph;
import com.lowagie.text.Table;
import com.lowagie.text.html.SAXmyHtmlHandler;
import com.lowagie.text.pdf.AcroFields;
import com.lowagie.text.pdf.BaseFont;
import com.lowagie.text.pdf.PdfReader;
import com.lowagie.text.pdf.PdfStamper;
import com.lowagie.text.pdf.PdfWriter;
import com.ynet.gene.core.Context;
import com.ynet.gene.data.KeyedCollection;
import com.ynet.life.base.Trace;
import com.ynet.life.exception.TranFailException;
import com.ynet.life.file.PDFDocumentFactory;
import java.io.FileOutputStream;
import java.io.IOException;
import java.io.StringReader;
import java.util.Iterator;
import java.util.List;
import javax.xml.parsers.SAXParser;
import javax.xml.parsers.SAXParserFactory;
import org.xml.sax.InputSource;
import org.xml.sax.helpers.DefaultHandler;

/* loaded from: com_ynet_life_file_parser.jar:com/ynet/life/file/parser/CommonPDFFileParser.class */
public class CommonPDFFileParser implements CommonFileParserInterface {
    @Override // com.ynet.life.file.parser.CommonFileParserInterface
    public void writeToFile(List titles, List recordList, List outputFields, List outputFormats, String filePathName, String encoding) throws TranFailException {
        try {
            Table table = new Table(outputFields.size());
            if (titles != null) {
                for (int i = 0; i < titles.size(); i++) {
                    String titleItem = (String) titles.get(i);
                    createCell(table, titleItem);
                }
            }
            Iterator iterator = recordList.iterator();
            while (iterator.hasNext()) {
                KeyedCollection record = (KeyedCollection) iterator.next();
                for (int i2 = 0; i2 < outputFields.size(); i2++) {
                    String fieldId = (String) outputFields.get(i2);
                    String str = (String) record.get(fieldId);
                    String fieldValue = str;
                    if (str == null) {
                        fieldValue = "";
                    }
                    String format = (String) outputFormats.get(i2);
                    createCell(table, FileParserUtil.transformFormat(fieldValue, format));
                }
            }
            Document document = new Document();
            FileOutputStream file = null;
            try {
                try {
                    file = new FileOutputStream(filePathName);
                    PdfWriter.getInstance(document, file);
                    document.open();
                    document.add(table);
                    try {
                        document.close();
                        file.close();
                    } catch (IOException e) {
                        Trace.logError("LifeFile", "资源释放出错", e);
                    }
                } catch (Throwable th) {
                    try {
                        document.close();
                        if (file != null) {
                            file.close();
                        }
                    } catch (IOException e2) {
                        Trace.logError("LifeFile", "资源释放出错", e2);
                    }
                    throw th;
                }
            } catch (Exception e3) {
                Trace.logError("LifeFile", "下载文件出错", e3);
                throw new TranFailException("EBLN0000", "下载文件出错");
            }
        } catch (BadElementException e4) {
            Trace.logError("LifeFile", "下载文件出错", e4);
            throw new TranFailException("EBLN0000", "下载文件出错");
        }
    }

    private void createCell(Table table, String content) {
        Cell cell = new Cell();
        try {
            BaseFont bf = BaseFont.createFont("STSong-Light", "UniGB-UCS2-H", false);
            Font fontChinese = new Font(bf, 12.0f, 0);
            cell.add(new Paragraph(content, fontChinese));
        } catch (Exception e) {
            Trace.logError("LifeFile", "下载文件时中文出错", e);
        }
        table.addCell(cell);
    }

    @Override // com.ynet.life.file.parser.CommonFileParserInterface
    public void writeToFile(List titles, List recordList, List outputFields, List outputFormats, String filePathName, String encoding, String expressionContent) throws TranFailException {
    }

    @Override // com.ynet.life.file.parser.CommonFileParserInterface
    public void writeToFile(List titles, List recordList, List outputFields, List outputFormats, String filePathName, String encoding, boolean seqFlag) throws TranFailException {
    }

    public static void createPdfFromTemplate(Context ctx, String templateFilePathName, String filePathName, String businessCode) throws TranFailException {
        try {
            PdfReader reader = new PdfReader(templateFilePathName);
            PdfStamper stamp = new PdfStamper(reader, new FileOutputStream(filePathName));
            AcroFields form = stamp.getAcroFields();
            for (String fieldName : form.getFields().keySet()) {
                form.setField(fieldName, FileParserUtil.transformFormat(new StringBuilder().append(ctx.get(fieldName)).toString(), DataFormatConfigProvider.getFieldAttrValue(fieldName, "type", businessCode), DataFormatConfigProvider.getFieldAttrValue(fieldName, "opt", businessCode)));
            }
            stamp.setFormFlattening(true);
            stamp.close();
        } catch (Exception e) {
            Trace.logError("LifeFile", "下载文件出错", e);
            throw new TranFailException("EBLN0000", "下载文件出错");
        }
    }

    public static void createPdfFromHtml(Context ctx, String filePathName, String content, String title) throws TranFailException {
        String content2 = "<html> <head><meta http-equiv=\"Content-Type\" content=\"text/html; charset=UTF-8\" /></head><body>" + content + "</body></html>";
        try {
            Document doc = PDFDocumentFactory.buildDocument(filePathName, title, (String) ctx.getDataValue("session_userName"));
            SAXParser parser = SAXParserFactory.newInstance().newSAXParser();
            BaseFont bf = BaseFont.createFont("STSong-Light", "UniGB-UCS2-H", false);
            parser.parse(new InputSource(new StringReader(content2)), (DefaultHandler) new SAXmyHtmlHandler(doc, bf));
            doc.close();
        } catch (Exception e) {
            Trace.logError("LifeFile", "下载文件出错", e);
            throw new TranFailException("EBLN0000", "下载文件出错");
        }
    }

    @Override // com.ynet.life.file.parser.CommonFileParserInterface
    public void writeToFile(List oneTitles, List twoTitles, List recordList, List outputFields, List titleColWidthFormats, List leftRightColMergeFormats, List topBottomColMergeFormats, String filePathName, String encoding, String reportTitle, List leftRightColMergeNum) throws TranFailException {
    }
}
